summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
Diffstat (limited to 'tools')
-rw-r--r--tools/install_venv.py10
-rw-r--r--tools/install_venv_common.py2
2 files changed, 4 insertions, 8 deletions
diff --git a/tools/install_venv_common.py b/tools/install_venv_common.py
index 1bab88a3f..46822e329 100644
--- a/tools/install_venv_common.py
+++ b/tools/install_venv_common.py
@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
# Copyright 2013 OpenStack Foundation
# Copyright 2013 IBM Corp.
#
diff --git a/tools/install_venv.py b/tools/install_venv.py
index 8ef3749c9..e96521ea2 100644
--- a/tools/install_venv.py
+++ b/tools/install_venv.py
@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
# Copyright 2010 United States Government as represented by the
# Administrator of the National Aeronautics and Space Administration.
# All Rights Reserved.
@@ -27,12 +25,12 @@ import install_venv_common as install_venv # noqa
def print_help(venv, root):
help = """
Openstack development environment setup is complete.
Openstack development uses virtualenv to track and manage Python
dependencies while in development and testing.
To activate the Openstack virtualenv for the extent of your current shell
session you can run:
$ source %s/bin/activate
@@ -59,7 +57,7 @@ def main(argv):
pip_requires = os.path.join(root, 'requirements.txt')
test_requires = os.path.join(root, 'test-requirements.txt')
py_version = "python%s.%s" % (sys.version_info[0], sys.version_info[1])
- project = 'Openstack'
+ project = 'OpenStack'
install = install_venv.InstallVenv(root, venv, pip_requires, test_requires,
py_version, project)
options = install.parse_args(argv)
@@ -27,12 +25,12 @@ import install_venv_common as install_venv # noqa
def print_help(venv, root):
help = """
- Openstack development environment setup is complete.
+ OpenStack development environment setup is complete.
- Openstack development uses virtualenv to track and manage Python
+ OpenStack development uses virtualenv to track and manage Python
dependencies while in development and testing.
@@ -27,12 +25,12 @@ import install_venv_common as install_venv # noqa
dependencies while in development and testing.
- To activate the Openstack virtualenv for the extent of your current shell
+ To activate the OpenStack virtualenv for the extent of your current shell
session you can run:
$ source %s/bin/activate